@@ -10,6 +10,15 @@ class Command(BaseCommand):
 
     def add_arguments(self, parser):
         parser.add_argument("args", metavar="dump", nargs="+", help="Dumps.")
+        parser.add_argument(
+            "--ignorenonexistent",
+            action="store_true",
+            dest="ignorenonexistent",
+            help=(
+                "Ignore entries in the serialized data for fields that do not"
+                " currently exist on the model.",
+            ),
+        )
 
     def handle(self, *dumps, **options):
         for dump in dumps:
@@ -18,4 +27,5 @@ class Command(BaseCommand):
             load_dump(
                 data,
                 progress=self.stderr.write if options["verbosity"] >= 2 else silence,
+                ignorenonexistent=options["ignorenonexistent"],
             )
